# pymembrane

PyMembrane is a Python library for modeling, simulating, and optimizing membrane-based food processes and wastewater treatment. It includes models for spiral membrane mass transfer, osmotic pressure calculations, and more.

## Simulation of Solute Mass Transfer in a Spiral Membrane

This project provides tools to simulate the transfer of solutes in a spiral membrane, including the modeling of different transport phenomena involved in the process.


For more details, visit the documentation at: https://pymembrane.readthedocs.io/